Changelog
=========

1.0 (2015-07-15)
----------------

- If ``UID`` is given in the catalog search keywords, don't apply the
  INavigationRoot path. This allows for explicit queries for known objects in
  other areas of the portal. Obsoletes pull-request #1.
  [thet]

- PEP 8.
  [thet]


1.0b1 (2009-03-29)
------------------

- Initial release.
  [optilude]
